@@ -38,6 +38,7 @@ def run(
     slurm_constraint: Optional[str] = None,
     slurm_partition: Optional[str] = None,
     slurm_maxjobs: Optional[int] = None,
+    slurm_args: Optional[str] = None,
     eventstream_host_ip: Optional[str] = None,
     eventstream_host_port: Optional[int] = None,
     **attributes: Any
@@ -93,6 +94,7 @@ def run(
         slurm_constraint=slurm_constraint,
         slurm_partition=slurm_partition,
         slurm_maxjobs=slurm_maxjobs,
+        slurm_args=slurm_args,
         host_ip=eventstream_host_ip,
         host_port=eventstream_host_port,
         eagersave=not no_save,
