@@ -18,6 +18,9 @@ from .base import attribute
 from .datascope_scenario import (
     DatascopeScenario,
     RepairMethod,
+    ModelSpec,
+    MODEL_TYPES,
+    MODEL_KWARGS,
     IMPORTANCE_METHODS,
     MC_ITERATIONS,
     DEFAULT_SEED,
@@ -40,7 +43,7 @@ from ..datasets import (
     DEFAULT_VALSIZE,
     DEFAULT_TESTSIZE,
 )
-from ..pipelines import Pipeline, ModelType, get_model
+from ..pipelines import Pipeline, get_model
 
 
 DEFAULT_DIRTY_RATIO = 0.5
@@ -63,7 +66,7 @@ class LabelRepairScenario(DatascopeScenario, id="label-repair"):
         method: RepairMethod,
         iteration: int,
         utility: UtilityType = UtilityType.ACCURACY,
-        model: ModelType = DEFAULT_MODEL,
+        model: ModelSpec = DEFAULT_MODEL,
         dirtyratio: float = DEFAULT_DIRTY_RATIO,
         dirtybias: float = DEFAULT_DIRTY_BIAS,
         seed: int = DEFAULT_SEED,
@@ -218,7 +221,9 @@ class LabelRepairScenario(DatascopeScenario, id="label-repair"):
         # provenance = binarize(provenance)
 
         # Initialize the model and utility.
-        model = get_model(self.model)
+        model_type = MODEL_TYPES[self.model]
+        model_kwargs = MODEL_KWARGS[self.model]
+        model = get_model(model_type, **model_kwargs)
         # model_pipeline = deepcopy(pipeline)
         # pipeline.steps.append(("model", model))
         # if RepairMethod.is_pipe(self.method):
